@@ -9,7 +9,7 @@ use XS::Install::Deps;
 use XS::Install::Util;
 use XS::Install::Payload;
 
-our $VERSION = '1.2.6';
+our $VERSION = '1.2.7';
 my $THIS_MODULE = 'XS::Install';
 
 our @EXPORT_OK = qw/write_makefile not_available/;
@@ -533,23 +533,45 @@ sub process_test {
         NO_MYMETA => 1,
         _XSTEST   => 1,
     );
+
+    push @{$params->{postamble}}, '# --- XS::Install tests compilation section';
     
+    my $mm_args;
+    # we might not have all TEST_REQUIRES, and that should not fail main Makefile, just forbid testing in current environment
+    my $ok = eval { $mm_args = makemaker_args(%args); 1 };
+
+    unless ($ok) {
+        my $err = $@;
+        $err =~ s/\r?\n/ /g;
+        push @{$params->{postamble}},
+            "subdirs-test_dynamic :: ctest",
+            "ctest ::\n".
+                "\t\@\$(ECHO) \"*******************************************************\"\n".
+                "\t\@\$(ECHO) \"******************** Can not test: ********************\"\n".
+                "\t\@\$(ECHO) \"*******************************************************\"\n".
+                "\t\@\$(ECHO) \"ERROR: $err\"\n".
+                "\t\@\$(ECHO) \"*******************************************************\"\n".
+                "\t\@\$(ECHO) \"******* REBUILD Makefile after resolving errors *******\"\n".
+                "\t\@\$(ECHO) \"*******************************************************\"\n".
+                "\t\@\$(PERL) -e 'exit(1)'",
+        ;
+        return undef;
+    }
+    
+    return undef unless has_binary($mm_args);
+
     my $make_params = '';
     $make_params .= ' --no-print-directory' if $linux;
     my $cmd = "\@\$(MAKE)$make_params -f Makefile.test";
     
     push @{$params->{postamble}},
-        '# --- XS::Install tests compilation section',
         "ctest_object : ; $cmd object",
         "ctest_ld : ctest_object \$(INST_DYNAMIC); $cmd",
         'subdirs-test_dynamic :: ctest_object ctest_ld',
         'ctest :: ctest_object ctest_ld',
         "clean :: ; $cmd veryclean",
     ;
-    
-    my $mm_args = makemaker_args(%args);
-    return undef unless has_binary($mm_args);
-    
+        
     if (my $prereq = $mm_args->{PREREQ_PM}) {
         my $testrq = $params->{TEST_REQUIRES};
         $testrq->{$_} //= $prereq->{$_} for grep {$_ ne $THIS_MODULE} keys %$prereq;
